public inbox for libstdc++@gcc.gnu.org
 help / color / mirror / Atom feed
* [PATCH] libstdc++: Fix 22_locale/numpunct/members/char/3.cc execution test
@ 2022-01-14 11:41 Uros Bizjak
  2022-01-14 12:13 ` Jonathan Wakely
  0 siblings, 1 reply; 2+ messages in thread
From: Uros Bizjak @ 2022-01-14 11:41 UTC (permalink / raw)
  To: gcc-patches, libstdc++

[-- Attachment #1: Type: text/plain, Size: 410 bytes --]

The test fails on Fedora 33+ because nl_NL locale got thousands
separator defined.  Use one of ar_SA, bg_BG, bs_BA, pt_PT
or plain C locale instead.

2022-01-14  Uroš Bizjak  <ubizjak@gmail.com>

libstdc++-v3/ChangeLog:

       * testsuite/22_locale/numpunct/members/char/3.cc (test02):
       Use pt_PT locale instead of nl_NL.

Tested on x86_64-linux-gnu (Fedora 33).

OK for master?

Uros.

[-- Attachment #2: p.diff.txt --]
[-- Type: text/plain, Size: 682 bytes --]

diff --git a/libstdc++-v3/testsuite/22_locale/numpunct/members/char/3.cc b/libstdc++-v3/testsuite/22_locale/numpunct/members/char/3.cc
index 6e4959860cd..4cf4b24407d 100644
--- a/libstdc++-v3/testsuite/22_locale/numpunct/members/char/3.cc
+++ b/libstdc++-v3/testsuite/22_locale/numpunct/members/char/3.cc
@@ -28,8 +28,8 @@ void test02()
 {
   using namespace std;
 
-  // nl_NL chosen because it has no thousands separator (at this time).
-  locale loc_it = locale(ISO_8859(15,nl_NL));
+  // pt_PT chosen because it has no thousands separator (at this time).
+  locale loc_it = locale(ISO_8859(15,pt_PT));
 
   const numpunct<char>& nump_it = use_facet<numpunct<char> >(loc_it); 
 

^ permalink raw reply	[flat|nested] 2+ messages in thread

* Re: [PATCH] libstdc++: Fix 22_locale/numpunct/members/char/3.cc execution test
  2022-01-14 11:41 [PATCH] libstdc++: Fix 22_locale/numpunct/members/char/3.cc execution test Uros Bizjak
@ 2022-01-14 12:13 ` Jonathan Wakely
  0 siblings, 0 replies; 2+ messages in thread
From: Jonathan Wakely @ 2022-01-14 12:13 UTC (permalink / raw)
  To: Uros Bizjak; +Cc: gcc-patches, libstdc++

On Fri, 14 Jan 2022 at 11:41, Uros Bizjak via Libstdc++ <
libstdc++@gcc.gnu.org> wrote:

> The test fails on Fedora 33+ because nl_NL locale got thousands
> separator defined.  Use one of ar_SA, bg_BG, bs_BA, pt_PT
> or plain C locale instead.
>
> 2022-01-14  Uroš Bizjak  <ubizjak@gmail.com>
>
> libstdc++-v3/ChangeLog:
>
>        * testsuite/22_locale/numpunct/members/char/3.cc (test02):
>        Use pt_PT locale instead of nl_NL.
>
> Tested on x86_64-linux-gnu (Fedora 33).
>
> OK for master?
>
>
Please also change the dg-require-namedlocale directive on the first line.

OK with that change, thanks.

^ permalink raw reply	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2022-01-14 12:13 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2022-01-14 11:41 [PATCH] libstdc++: Fix 22_locale/numpunct/members/char/3.cc execution test Uros Bizjak
2022-01-14 12:13 ` Jonathan Wakely

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).